@@ -12,12 +12,12 @@ from flask import jsonify
 
 
 def cloneRepo(data):
-  """Clonne a repository
+  """Clone a repository
   Args:
-    data: a dictionnary of parameters to use:
+    data: a dictionary of parameters to use:
       data['path'] is the path of the new project
       data['repo'] is the url of the repository to be cloned
-      data['email'] is the user email
+      data['email'] is the user's email
       data['user'] is the name of the user
   Returns:
     a jsonify data"""
@@ -29,7 +29,7 @@ def cloneRepo(data):
   json = ""
   try:
     if os.path.exists(workDir) and len(os.listdir(workDir)) < 2:
-      shutil.rmtree(workDir) #delete useless files
+      shutil.rmtree(workDir)  # delete useless files
     repo = Repo.clone_from(data["repo"], workDir)
     config_writer = repo.config_writer()
     config_writer.add_section("user")
@@ -42,10 +42,11 @@ def cloneRepo(data):
     json = safeResult(str(e))
   return jsonify(code=code, result=json)
 
+
 def gitStatus(project):
   """Run git status and return status of specified project folder
   Args:
-    project: path of the projet ti get status
+    project: path of the projet to get status
   Returns:
     a parsed string that contains the result of git status"""
   code = 0
@@ -61,6 +62,7 @@ def gitStatus(project):
     json = safeResult(str(e))
   return jsonify(code=code, result=json, branch=branch, dirty=isdirty)
 
+
 def switchBranch(project, name):
   """Switch a git branch
   Args:
@@ -76,13 +78,14 @@ def switchBranch(project, name):
     if name == current_branch:
       json = "This is already your active branch for this project"
     else:
-      git  = repo.git
+      git = repo.git
       git.checkout(name)
       code = 1
   except Exception as e:
     json = safeResult(str(e))
   return jsonify(code=code, result=json)
 
+
 def addBranch(project, name, onlyCheckout=False):
   """Add new git branch to the repository
   Args:
@@ -95,7 +98,7 @@ def addBranch(project, name, onlyCheckout=False):
   json = ""
   try:
     repo = Repo(project)
-    git  = repo.git
+    git = repo.git
     if not onlyCheckout:
       git.checkout('-b', name)
     else:
@@ -105,6 +108,7 @@ def addBranch(project, name, onlyCheckout=False):
     json = safeResult(str(e))
   return jsonify(code=code, result=json)
 
+
 def getDiff(project):
   """Get git diff for the specified project directory"""
   result = ""
@@ -117,6 +121,7 @@ def getDiff(project):
     result = safeResult(str(e))
   return result
 
+
 def gitPush(project, msg):
   """Commit and Push changes for the specified repository
   Args:
@@ -141,14 +146,15 @@ def gitPush(project, msg):
       git.push('origin', current_branch)
       code = 1
     else:
-      json = "Nothing to be commited"
+      json = "Nothing to commit"
       code = 1
   except Exception as e:
     if undo_commit:
-      git.reset("HEAD~") #undo previous commit
+      git.reset("HEAD~")  # undo previous commit
     json = safeResult(str(e))
   return jsonify(code=code, result=json)
 
+
 def gitPull(project):
   result = ""
   code = 0
@@ -161,6 +167,7 @@ def gitPull(project):
     result = safeResult(str(e))
   return jsonify(code=code, result=result)
 
+
 def safeResult(result):
   """Parse string and remove credential of the user"""
   regex = re.compile("(https:\/\/)([\w\d\._-]+:[\w\d\._-]+)\@([\S]+\s)", re.VERBOSE)
