@@ -41,38 +41,46 @@ file_request = FileBrowser(app.config)
 import logging
 logger = logging.getLogger('werkzeug')
 
+
 def login_redirect(*args, **kwargs):
   return redirect(url_for('login'))
 
+
 #Access Control: Only static files and login pages are allowed to guest
 @app.before_request
 def before_request():
-  if not request.path.startswith('/static'):
-    account = getSession(app.config)
-    if account:
-      user = AuthUser(username=account[0])
-      user.set_and_encrypt_password(account[1], "123400ZYX")
-      session['title'] = getProjectTitle(app.config)
-      g.users = {account[0]: user}
-    else:
-      session['title'] = "No account is defined"
-      if request.path != "/setAccount" and request.path != "/configAccount":
-        return redirect(url_for('setAccount'))
+  if request.path.startswith('/static'):
+    return
+
+  account = getSession(app.config)
+  if account:
+    user = AuthUser(username=account[0])
+    user.set_and_encrypt_password(account[1], "123400ZYX")
+    session['title'] = getProjectTitle(app.config)
+    g.users = {account[0]: user}
+  else:
+    session['title'] = "No account is defined"
+    if request.path != "/setAccount" and request.path != "/configAccount":
+      return redirect(url_for('setAccount'))
+
 
 # general views
 @login_required()
 def home():
   return render_template('index.html')
 
+
 # general views
 @login_required()
 def browseWorkspace():
   return render_template('workspace.html')
 
+
 @app.route("/login")
 def login():
   return render_template('login.html')
 
+
 @app.route("/setAccount")
 def setAccount():
   account = getSession(app.config)
@@ -80,25 +88,29 @@ def setAccount():
     return render_template('account.html')
   return redirect(url_for('login'))
 
+
 @login_required()
 def myAccount():
   account = getSession(app.config)
   return render_template('account.html', username=account[0],
           email=account[2], name=account[3].decode('utf-8'))
 
+
 @app.route("/dologout")
 def dologout():
   _ = logout()
   return redirect(url_for('login'))
 
+
 @login_required()
 def configRepo():
-  public_key = open(app.config['public_key'], 'r').read()
+  public_key = open(app.config['public_key']).read()
   account = getSession(app.config)
   return render_template('cloneRepository.html', workDir='workspace',
             public_key=public_key, name=account[3].decode('utf-8'),
             email=account[2])
 
+
 @app.route("/doLogin", methods=['POST'])
 def doLogin():
   username = request.form['clogin']
@@ -106,7 +118,8 @@ def doLogin():
     # Authenticate and log in!
     if g.users[username].authenticate(request.form['cpwd']):
       return jsonify(code=1, result="")
-  return jsonify(code=0, result="Login or password is incorrect, please check it!")
+  return jsonify(code=0, result="Login or password is incorrect, please check it!"), 401
+
 
 # software views
 @login_required()
@@ -117,11 +130,13 @@ def editSoftwareProfile():
   return render_template('updateSoftwareProfile.html', workDir='workspace',
       profile=profile, projectList=getProjectList(app.config['workspace']))
 
+
 @login_required()
 def inspectSoftware():
   return render_template('runResult.html', softwareRoot='software_link/',
                          softwares=loadSoftwareRList(app.config))
 
+
 #remove content of compiled software release
 @login_required()
 def removeSoftware():
@@ -135,22 +150,25 @@ def removeSoftware():
     flash('Software removed')
   return redirect(url_for('inspectSoftware'))
 
+
 @login_required()
 def runSoftwareProfile():
   if runSoftwareWithLock(app.config):
-    return  jsonify(result = True)
+    return jsonify(result=True)
   else:
-    return  jsonify(result = False)
+    return jsonify(result=False)
+
 
 @login_required()
 def viewSoftwareLog():
   if os.path.exists(app.config['software_log']):
-    result = tail(open(app.config['software_log'], 'r'), lines=1500)
+    result = tail(open(app.config['software_log']), lines=1500)
   else:
     result = 'Not found yet'
   return render_template('viewLog.html', type='software',
       result=result.encode("utf-8"))
 
+
 # instance views
 @login_required()
 def editInstanceProfile():
@@ -160,50 +178,48 @@ def editInstanceProfile():
   return render_template('updateInstanceProfile.html', workDir='workspace',
       profile=profile, projectList=getProjectList(app.config['workspace']))
 
+
 # get status of all computer partitions and process state
 @login_required()
 def inspectInstance():
-  file_content = ''
-  result = ''
   if os.path.exists(app.config['instance_root']):
-    file_content = 'instance_root'
-    result = getSvcStatus(app.config)
-    if len(result) == 0:
-      result = []
+    file_path = 'instance_root'
+    supervisor = getSvcStatus(app.config)
+  else:
+    file_path = ''
+    supervisor = []
   return render_template('instanceInspect.html',
-      file_path=file_content, supervisor=result,
-      slap_status=getSlapStatus(app.config),
-      supervisore=result, partition_amount=app.config['partition_amount'])
+                         file_path=file_path,
+                         supervisor=supervisor,
+                         slap_status=getSlapStatus(app.config),
+                         partition_amount=app.config['partition_amount'])
+
 
 #Reload instance process ans returns new value to ajax
 @login_required()
 def supervisordStatus():
   result = getSvcStatus(app.config)
-  if not (result):
+  if not result:
     return jsonify(code=0, result="")
+  # XXX-Marco -> template
   html = "<tr><th>Partition and Process name</th><th>Status</th><th>Process PID </th><th> UpTime</th><th></th></tr>"
   for item in result:
     html += "<tr>"
-    html += "<td  class='first'><b><a href='" \
-        + url_for('tailProcess', process=item[0]) + "'>" \
-        + item[0] + "</a></b></td>"
-    html += "<td align='center'><a href='" \
-        + url_for('startStopProccess', process=item[0], action=item[1]) \
-        + "'>" + item[1] + "</a></td>"
+    html += "<td  class='first'><b><a href='" + url_for('tailProcess', process=item[0]) + "'>" + item[0] + "</a></b></td>"
+    html += "<td align='center'><a href='" + url_for('startStopProccess', process=item[0], action=item[1]) + "'>" + item[1] + "</a></td>"
     html += "<td align='center'>" + item[3] + "</td><td>" + item[5] + "</td>"
-    html += "<td align='center'><a href='" \
-        + url_for('startStopProccess', process=item[0], action='RESTART') \
-        + "'>Restart</a></td>"
+    html += "<td align='center'><a href='" + url_for('startStopProccess', process=item[0], action='RESTART') + "'>Restart</a></td>"
     html += "</tr>"
   return jsonify(code=1, result=html)
 
+
 @login_required()
 def removeInstance():
   if isInstanceRunning(app.config):
     flash('Instantiation in progress, cannot remove')
   else:
     removeProxyDb(app.config)
-    svcStopAll(app.config) #Stop All instance process
+    svcStopAll(app.config)  # Stop All instance process
     removeInstanceRoot(app.config)
     param_path = os.path.join(app.config['etc_dir'], ".parameter.xml")
     if os.path.exists(param_path):
@@ -211,67 +227,83 @@ def removeInstance():
     flash('Instance removed')
   return redirect(url_for('inspectInstance'))
 
+
 @login_required()
 def runInstanceProfile():
   if not os.path.exists(app.config['instance_root']):
     os.mkdir(app.config['instance_root'])
   if runInstanceWithLock(app.config):
-    return  jsonify(result = True)
+    return jsonify(result=True)
   else:
-    return  jsonify(result = False)
+    return jsonify(result=False)
+
 
 @login_required()
 def viewInstanceLog():
   if os.path.exists(app.config['instance_log']):
-    result = open(app.config['instance_log'], 'r').read()
+    result = open(app.config['instance_log']).read()
   else:
     result = 'Not found yet'
   return render_template('viewLog.html', type='instance',
       result=result.encode("utf-8"))
 
+
 @login_required()
 def stopAllPartition():
   svcStopAll(app.config)
   return redirect(url_for('inspectInstance'))
 
+
 @login_required(login_redirect)
 def tailProcess(process):
   return render_template('processTail.html',
       process_log=getSvcTailProcess(app.config, process), process=process)
 
+
 @login_required(login_redirect)
 def startStopProccess(process, action):
   svcStartStopProcess(app.config, process, action)
   return redirect(url_for('inspectInstance'))
 
+
 @login_required(login_redirect)
 def openProject(method):
   return render_template('projectFolder.html', method=method,
                          workDir='workspace')
 
+
 @login_required()
 def cloneRepository():
   path = realpath(app.config, request.form['name'], False)
-  data = {"repo":request.form['repo'], "user":request.form['user'],
-          "email":request.form['email'], "path":path}
+  data = {
+    'repo': request.form['repo'],
+    'user': request.form['user'],
+    'email': request.form['email'],
+    'path': path
+  }
   return cloneRepo(data)
 
+
 @login_required()
 def readFolder():
   return getFolderContent(app.config, request.form['dir'])
 
+
 @login_required()
 def openFolder():
   return getFolder(app.config, request.form['dir'])
 
+
 @login_required()
 def createSoftware():
   return newSoftware(request.form['folder'], app.config, session)
 
+
 @login_required()
 def checkFolder():
   return checkSoftwareFolder(request.form['path'], app.config)
 
+
 @login_required()
 def setCurrentProject():
   if configNewSR(app.config, request.form['path']):
@@ -280,11 +312,13 @@ def setCurrentProject():
   else:
     return jsonify(code=0, result=("Can not setup this Software Release"))
 
+
 @login_required()
 def manageProject():
   return render_template('manageProject.html', workDir='workspace',
                          project=getProjectList(app.config['workspace']))
 
+
 @login_required()
 def getProjectStatus():
   path = realpath(app.config, request.form['project'])
@@ -293,6 +327,7 @@ def getProjectStatus():
   else:
     return jsonify(code=0, result="Can not read folder: Permission Denied")
 
+
 #view for current software release files
 @login_required()
 def editCurrentProject():
@@ -303,13 +338,13 @@ def editCurrentProject():
                            projectList=getProjectList(app.config['workspace']))
   return redirect(url_for('configRepo'))
 
+
 #create file or directory
 @login_required()
 def createFile():
   path = realpath(app.config, request.form['file'], False)
   if not path:
-    return jsonify(code=0, result="Error when creating your " + \
-                   request.form['type'] + ": Permission Denied")
+    return jsonify(code=0, result="Error when creating your %s: Permission Denied" % request.form['type'])
   try:
     if request.form['type'] == "file":
       open(path, 'w')
@@ -319,6 +354,7 @@ def createFile():
   except Exception as e:
     return jsonify(code=0, result=str(e))
 
+
 #remove file or directory
 @login_required()
 def removeFile():
@@ -331,6 +367,7 @@ def removeFile():
   except Exception as e:
     return jsonify(code=0, result=str(e))
 
+
 @login_required()
 def removeSoftwareDir():
   try:
@@ -340,6 +377,7 @@ def removeSoftwareDir():
   except Exception as e:
     return jsonify(code=0, result=str(e))
 
+
 #read file and return content to ajax
 @login_required()
 def getFileContent():
@@ -348,14 +386,15 @@ def getFileContent():
     if not isText(file_path):
       return jsonify(code=0,
             result="Can not open a binary file, please select a text file!")
-    if not request.form.has_key('truncate'):
-      return jsonify(code=1, result=open(file_path, 'r').read())
-    else:
-      content = tail(open(file_path, 'r'), int(request.form['truncate']))
+    if 'truncate' in request.form:
+      content = tail(open(file_path), int(request.form['truncate']))
       return jsonify(code=1, result=content)
+    else:
+      return jsonify(code=1, result=open(file_path).read())
   else:
     return jsonify(code=0, result="Error: No such file!")
 
+
 @login_required()
 def saveFileContent():
   file_path = realpath(app.config, request.form['file'])
@@ -365,6 +404,7 @@ def saveFileContent():
   else:
     return jsonify(code=0, result="Error: No such file!")
 
+
 @login_required()
 def changeBranch():
   path = realpath(app.config, request.form['project'])
@@ -373,6 +413,7 @@ def changeBranch():
   else:
     return jsonify(code=0, result="Can not read folder: Permission Denied")
 
+
 @login_required()
 def newBranch():
   path = realpath(app.config, request.form['project'])
@@ -384,12 +425,14 @@ def newBranch():
   else:
     return jsonify(code=0, result="Can not read folder: Permission Denied")
 
+
 @login_required(login_redirect)
 def getProjectDiff(project):
   path = os.path.join(app.config['workspace'], project)
   return render_template('projectDiff.html', project=project,
                            diff=getDiff(path))
 
+
 @login_required()
 def pushProjectFiles():
   path = realpath(app.config, request.form['project'])
@@ -398,6 +441,7 @@ def pushProjectFiles():
   else:
     return jsonify(code=0, result="Can not read folder: Permission Denied")
 
+
 @login_required()
 def pullProjectFiles():
   path = realpath(app.config, request.form['project'])
@@ -406,6 +450,7 @@ def pullProjectFiles():
   else:
     return jsonify(code=0, result="Can not read folder: Permission Denied")
 
+
 @login_required()
 def checkFileType():
   path = realpath(app.config, request.form['path'])
@@ -417,6 +462,7 @@ def checkFileType():
     return jsonify(code=0,
                    result="Can not open a binary file, please select a text file!")
 
+
 @login_required()
 def getmd5sum():
   realfile = realpath(app.config, request.form['file'])
@@ -428,26 +474,32 @@ def getmd5sum():
   else:
     return jsonify(code=0, result="Can not get md5sum for this file!")
 
+
 #return information about state of slapgrid process
 @login_required()
 def slapgridResult():
   software_state = isSoftwareRunning(app.config)
   instance_state = isInstanceRunning(app.config)
-  log_result = {"content":"", "position":0, "truncated":False}
-  if request.form['log'] == "software"  or\
-     request.form['log'] == "instance":
+  log_result = {
+    'content': '',
+    'position': 0,
+    'truncated': False
+  }
+  if request.form['log'] in ['software', 'instance']:
     log_file = request.form['log'] + "_log"
     if os.path.exists(app.config[log_file]):
-      log_result = readFileFrom(open(app.config[log_file], 'r'),
-                            int(request.form['position']))
-  return  jsonify(software=software_state, instance=instance_state,
-                  result=(instance_state or software_state), content=log_result)
+      log_result = readFileFrom(open(app.config[log_file]),
+                                int(request.form['position']))
+  return jsonify(software=software_state, instance=instance_state,
+                 result=(instance_state or software_state), content=log_result)
+
 
 @login_required()
 def stopSlapgrid():
   result = killRunningProcess(request.form['type'])
   return jsonify(result=result)
 
+
 @login_required()
 def getPath():
   files = request.form['file'].split('#')
@@ -466,6 +518,7 @@ def getPath():
   else:
     return jsonify(code=1, result=realfile)
 
+
 @login_required()
 def saveParameterXml():
   """
@@ -477,12 +530,11 @@ def saveParameterXml():
   content = request.form['parameter'].encode("utf-8")
   param_path = os.path.join(app.config['etc_dir'], ".parameter.xml")
   try:
-    f = open(param_path, 'w')
-    f.write(content)
-    f.close()
+    with open(param_path, 'w') as f:
+      f.write(content)
     result = readParameters(param_path)
   except Exception as e:
-      result = str(e)
+    result = str(e)
   software_type = None
   if request.form['software_type']:
     software_type = request.form['software_type']
@@ -494,26 +546,27 @@ def saveParameterXml():
     except Exception as e:
       return jsonify(
         code=0,
-        result="An error occurred while applying your settings!<br/>" + str(e))
+        result="An error occurred while applying your settings!<br/>%s" % e)
     return jsonify(code=1, result="")
 
+
 @login_required()
 def getSoftwareType():
   software_type_path = os.path.join(app.config['etc_dir'], ".software_type.xml")
   if os.path.exists(software_type_path):
-    return jsonify(code=1, result=open(software_type_path, 'r').read())
+    return jsonify(code=1, result=open(software_type_path).read())
   return jsonify(code=1, result="default")
 
+
 #read instance parameters into the local xml file and return a dict
 @login_required()
 def getParameterXml(request):
   param_path = os.path.join(app.config['etc_dir'], ".parameter.xml")
   if not os.path.exists(param_path):
-    default = '<?xml version="1.0" encoding="utf-8"?>\n'
-    default += '<instance>\n</instance>'
+    default = '<?xml version="1.0" encoding="utf-8"?>\n<instance>\n</instance>'
     return jsonify(code=1, result=default)
   if request == "xml":
-    parameters = open(param_path, 'r').read()
+    parameters = open(param_path).read()
   else:
     parameters = readParameters(param_path)
   if type(parameters) == type('') and request != "xml":
@@ -521,16 +574,44 @@ def getParameterXml(request):
   else:
     return jsonify(code=1, result=parameters)
 
+
 #update user account data
 @login_required()
 def updateAccount():
+  code = request.form['rcode'].strip()
+  recovery_code = open(os.path.join(app.config['etc_dir'], ".rcode"), "r").read()
+  if code != recovery_code:
+    return jsonify(code=0, result="Your password recovery code is not valid!")
+
+  account = [
+    request.form['username'].strip(),
+    request.form['password'].strip(),
+    request.form['email'].strip(),
+    request.form['name'].strip()
+  ]
+  result = saveSession(app.config, account)
+  if type(result) == type(""):
+    return jsonify(code=0, result=result)
+  else:
+    return jsonify(code=1, result="")
+
+
+#update user account data
+@app.route("/configAccount", methods=['POST'])
+def configAccount():
+  last_account = getSession(app.config)
+  if last_account:
+    return jsonify(code=0,
+                   result="Unable to respond to your request, permission denied.")
+
   account = []
   account.append(request.form['username'].strip())
   account.append(request.form['password'].strip())
   account.append(request.form['email'].strip())
   account.append(request.form['name'].strip())
   code = request.form['rcode'].strip()
-  recovery_code = open(os.path.join(app.config['etc_dir'], ".rcode"), "r").read()
+  recovery_code = open(os.path.join(app.config['etc_dir'], ".rcode"),
+                      "r").read()
   if code != recovery_code:
     return jsonify(code=0, result="Your password recovery code is not valid!")
   result = saveSession(app.config, account)
@@ -539,28 +620,6 @@ def updateAccount():
   else:
     return jsonify(code=1, result="")
 
-#update user account data
-@app.route("/configAccount", methods=['POST'])
-def configAccount():
-  last_account = getSession(app.config)
-  if not last_account:
-    account = []
-    account.append(request.form['username'].strip())
-    account.append(request.form['password'].strip())
-    account.append(request.form['email'].strip())
-    account.append(request.form['name'].strip())
-    code = request.form['rcode'].strip()
-    recovery_code = open(os.path.join(app.config['etc_dir'], ".rcode"),
-                        "r").read()
-    if code != recovery_code:
-      return jsonify(code=0, result="Your password recovery code is not valid!")
-    result = saveSession(app.config, account)
-    if type(result) == type(""):
-      return jsonify(code=0, result=result)
-    else:
-      return jsonify(code=1, result="")
-  return jsonify(code=0,
-                 result="Unable to respond to your request, permission denied.")
 
 #Global File Manager
 @login_required()
@@ -576,6 +635,7 @@ def fileBrowser():
       opt = int(request.form['opt'])
   else:
     opt = int(request.args.get('opt'))
+
   try:
     if opt == 1:
       #list files and directories
@@ -626,6 +686,7 @@ def fileBrowser():
     return str(e)
   return result
 
+
 @login_required()
 def editFile():
   return render_template('editFile.html', workDir='workspace',
@@ -633,6 +694,7 @@ def editFile():
     projectList=getProjectList(app.config['workspace']),
     filename=urllib.unquote(request.args.get('filename', '')))
 
+
 #Setup List of URLs
 app.add_url_rule('/', 'home', home)
 app.add_url_rule('/browseWorkspace', 'browseWorkspace', browseWorkspace)
